@@ -133,8 +133,7 @@ namespace Lum {
     if (!visible ||
         !adjustment.Valid() ||
         !adjustment->IsValid() ||
-        !adjustment->IsEnabled() ||
-        !OS::display->GetBehaviour()->ScrollKnobActive()) {
+        !adjustment->IsEnabled()) {
       return false;
     }
 
@@ -197,8 +196,7 @@ namespace Lum {
     if (!visible ||
         !adjustment.Valid() ||
         !adjustment->IsValid() ||
-        !adjustment->IsEnabled() ||
-        !OS::display->GetBehaviour()->ScrollKnobActive()) {
+        !adjustment->IsEnabled()) {
       return false;
     }
 
