@@ -181,11 +181,12 @@ namespace Lum {
      */
     void Adjustment::SetTop(size_t top)
     {
-      if (top>=1 && top<=total->Get()-visible->Get()+1) {
-        if (this->top->IsNull() || this->top->Get()!=top) {
-          this->top->Set(top);
-          Notify();
-        }
+      assert(top);
+      assert(top<=total->Get()-visible->Get()+1);
+
+      if (this->top->IsNull() || this->top->Get()!=top) {
+        this->top->Set(top);
+        Notify();
       }
     }
 
@@ -218,7 +219,7 @@ namespace Lum {
       }
 
       if (top+visible>total) {
-          top=total-visible+1;
+        top=total-visible+1;
       }
 
       Set(top,visible,total);
